@@ -8,6 +8,10 @@ def task_router (state: GraphState) -> str:
         return 'maker'
     elif state['task']=='methods_generation':
         return 'methods'
+    elif state['task']=='literature':
+        return 'novelty'
+    elif state['task']=='referee':
+        return 'referee'
     else:
         raise Exception('Wrong task choosen!')
     
@@ -18,3 +22,10 @@ def router(state: GraphState) -> str:
         return "hater"
     else: 
         return "__end__"
+
+def literature_router(state: GraphState) -> str:
+    """
+    This simple function determines which agent should go after calling the novelty_decider one
+    """
+
+    return state['literature']['next_agent']
