@@ -50,11 +50,26 @@ gpt45 = LLM(name="gpt-4.5-preview-2025-02-27",
             temperature=0.5)
 """`gpt-4.5-preview` model."""
 
+gpt5 = LLM(name="gpt-5",
+           max_output_tokens=128000,
+           temperature=None)
+"""`gpt-5` model """
+
 claude37sonnet = LLM(name="claude-3-7-sonnet-20250219",
                      max_output_tokens=64000,
                      temperature=0)
 """`claude-3-7-sonnet` model."""
 
+claude4opus = LLM(name="claude-opus-4-20250514",
+                   max_output_tokens=32000,
+                   temperature=0)
+"""`claude-4-Opus` model."""
+
+claude41opus = LLM(name="claude-opus-4-1-20250805",
+                   max_output_tokens=32000,
+                   temperature=0)
+"""`claude-4.1-Opus` model."""
+
 models : Dict[str, LLM] = {
                             "gemini-2.0-flash" : gemini20flash,
                             "gemini-2.5-flash" : gemini25flash,
@@ -64,6 +79,9 @@ models : Dict[str, LLM] = {
                             "gpt-4.1" : gpt41,
                             "gpt-4o-mini" : gpt4omini,
                             "gpt-4.5" : gpt45,
+                            "gpt-5" : gpt5,
                             "claude-3.7-sonnet" : claude37sonnet,
+                            "claude-4-opus" : claude4opus,
+                            "claude-4.1-opus" : claude41opus,
                            }
 """Dictionary with the available models."""
